@@ -1,4 +1,4 @@
-# $Id: DBD.pm,v 11.7 2002/07/15 11:18:57 timbo Exp $
+# $Id: DBD.pm,v 11.8 2002/07/18 14:23:44 timbo Exp $
 #
 # Copyright (c) 1997-2000 Jonathan Leffler, Jochen Wiedmann and Tim Bunce
 #
@@ -15,8 +15,8 @@ DBI::DBD - DBD Driver Writer's Guide
 
 =head1 VERSION and VOLATILITY
 
-  $Revision: 11.7 $
-  $Date: 2002/07/15 11:18:57 $
+  $Revision: 11.8 $
+  $Date: 2002/07/18 14:23:44 $
 
 This document is a minimal draft which is in need of further work.
 
@@ -1756,7 +1756,7 @@ use DBI::Const::GetInfoType qw(%GetInfoType);
 
 @ISA = qw(Exporter);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 11.7 $ =~ /(\d+)\.(\d+)/o);
+$VERSION = sprintf("%d.%02d", q$Revision: 11.8 $ =~ /(\d+)\.(\d+)/o);
 
 @EXPORT = qw(
     dbd_dbi_dir dbd_dbi_arch_dir
@@ -1834,15 +1834,17 @@ sub dbd_postamble {
     my $dbidir = dbd_dbi_dir();
     my $xstdir = dbd_dbi_arch_dir();
     my $xstfile= '$(DBI_INSTARCH_DIR)/Driver.xst';
+    my $xstf_h = '$(DBI_INSTARCH_DIR)/Driver_xst.h';
     if ($^O eq 'VMS') {
 	$dbidir = vmsify($dbidir.'/');
 	$xstdir = vmsify($xstdir.'/') unless $is_dbi;
 	$xstfile= '$(DBI_INSTARCH_DIR)Driver.xst';
+	$xstf_h = '$(DBI_INSTARCH_DIR)Driver_xst.h';
     }
 
     # we must be careful of quotes, expecially for Win32 here.
     '
-# This section was generated by DBI::DBD::dbd_postamble()
+# --- This section was generated by DBI::DBD::dbd_postamble()
 DBI_INST_DIR='.$dbidir.'
 DBI_INSTARCH_DIR='.$xstdir.'
 DBI_DRIVER_XST='.$xstfile.'
@@ -1853,8 +1855,10 @@ $(BASEEXT).c: $(BASEEXT).xsi
 # This dependancy is needed since MakeMaker uses the .xs.o rule
 $(BASEEXT)$(OBJ_EXT): $(BASEEXT).xsi
 
-$(BASEEXT).xsi: $(DBI_DRIVER_XST)
+$(BASEEXT).xsi: $(DBI_DRIVER_XST) '.$xstf_h.'
 	$(PERL) -p -e "s/~DRIVER~/$(BASEEXT)/g" < $(DBI_DRIVER_XST) > $(BASEEXT).xsi
+
+# ---
 ';
 }
 
